@@ -1,4 +1,4 @@
-/* $Id: rapi.h,v 1.35 2004/05/22 15:56:54 twogood Exp $ */
+/* $Id: rapi.h 2509 2006-07-03 21:08:59Z oleavr $ */
 #ifndef __rapi_h__
 #define __rapi_h__
 
@@ -6,15 +6,15 @@
  * Note on #ifndef SWIG preprocessor token.
  *
  * The scripting langauge code in the pyrapi module uses
- * SWIG to generate the python wrapper code. To enable SWIG to 
- * parse this header file some parts of it must be 
- * selectively removed. SWIG defines "SWIG" as a 
+ * SWIG to generate the python wrapper code. To enable SWIG to
+ * parse this header file some parts of it must be
+ * selectively removed. SWIG defines "SWIG" as a
  * preproccessor token when is it parsing headers.
  * Therefore where you see #ifndef SWIG declarations
  * in this header they are intended to remove elements for
  * which the SWIG wrapper provides alternative
  * declarations. In most cases this is type and function
- * declarations. 
+ * declarations.
  */
 
 #ifndef SWIG
@@ -28,6 +28,57 @@ extern "C"
 {
 #endif
 
+/*
+ * SynCE support for switching between multiple devices
+ *
+ * Example code for two devices follows!
+ *
+ * It shows two different ways to get a RapiConnection object.
+ *
+ *   RapiConnection* a = rapi_connection_from_path("/home/david/.synce/a");
+ *   rapi_connection_select(a);
+ *   CeRapiInit()
+ *
+ *   SynceInfo* info_b = synce_info_new("/home/david/.synce/b");
+ *   RapiConnection* b = rapi_connection_from_info(info_b);
+ *   rapi_connection_select(b);
+ *   CeRapiInit()
+ *
+ *   rapi_connection_select(a);
+ *   ...some RAPI calls to device A...
+ *
+ *   rapi_connection_select(b);
+ *   ...some RAPI calls to device B...
+ *
+ *   rapi_connection_select(a);
+ *   CeRapiUninit();
+ *   rapi_connection_destroy(a);
+ *
+ *   rapi_connection_select(b);
+ *   CeRapiUninit();
+ *   rapi_connection_destroy(b);
+ */
+
+typedef struct _RapiConnection RapiConnection;
+
+/**
+ * Create a connection - use this before you call CeRapiInit()
+ *
+ * @path Parameter sent to synce_info_new() in libsynce/lib/info.c
+ */
+RapiConnection* rapi_connection_from_path(const char* path);
+
+/**
+ * Create a connection - low-level version
+ */
+RapiConnection* rapi_connection_from_info(SynceInfo* info);
+
+/** Select what connection is used for RAPI calls */
+void rapi_connection_select(RapiConnection* connection);
+
+/** Destroy connection object - use this after CeRapiUninit() */
+void rapi_connection_destroy(RapiConnection* connection);
+
 /*
  * Main RAPI functions
  */
@@ -35,8 +86,8 @@ extern "C"
 #define CERAPI_E_ALREADYINITIALIZED  0x8004101
 
 #ifndef SWIG
-	
-HRESULT CeRapiFreeBuffer( 
+
+HRESULT CeRapiFreeBuffer(
 		LPVOID Buffer);
 
 HRESULT CeRapiInit(void);
@@ -45,6 +96,10 @@ STDAPI CeRapiUninit(void);
 
 HRESULT CeRapiGetError(void);
 
+/** Not part of the real RAPI.
+ * Use it instead of Win32's GetLastError() */
+DWORD CeRapiGetLastError();
+
 #endif /* SWIG */
 
 
@@ -91,37 +146,61 @@ HRESULT CeRapiGetError(void);
 #define FILE_ATTRIBUTE_6          0x00040000
 #define FILE_ATTRIBUTE_7          0x00080000
 
+/* dwMoveMethod */
+#define FILE_BEGIN      0
+#define FILE_CURRENT    1
+#define FILE_END        2
+
+
 #ifndef SWIG
 
-BOOL CeCloseHandle( 
+BOOL CeCloseHandle(
 		HANDLE hObject);
 
 typedef void* LPSECURITY_ATTRIBUTES;
 
 HANDLE CeCreateFile(
-		LPCWSTR lpFileName, 
-		DWORD dwDesiredAccess, 
-		DWORD dwShareMode, 
-		LPSECURITY_ATTRIBUTES lpSecurityAttributes, 
-		DWORD dwCreationDisposition, 
-		DWORD dwFlagsAndAttributes, 
-		HANDLE hTemplateFile); 
+		LPCWSTR lpFileName,
+		DWORD dwDesiredAccess,
+		DWORD dwShareMode,
+		LPSECURITY_ATTRIBUTES lpSecurityAttributes,
+		DWORD dwCreationDisposition,
+		DWORD dwFlagsAndAttributes,
+		HANDLE hTemplateFile);
 
 typedef void* LPOVERLAPPED;
 
-BOOL CeReadFile( 
-		HANDLE hFile, 
-		LPVOID lpBuffer, 
-		DWORD nNumberOfBytesToRead, 
-		LPDWORD lpNumberOfBytesRead, 
+BOOL CeReadFile(
+		HANDLE hFile,
+		LPVOID lpBuffer,
+		DWORD nNumberOfBytesToRead,
+		LPDWORD lpNumberOfBytesRead,
 		LPOVERLAPPED lpOverlapped);
 
-BOOL CeWriteFile( 
-		HANDLE hFile, 
-		LPCVOID lpBuffer, 
-		DWORD nNumberOfBytesToWrite, 
-		LPDWORD lpNumberOfBytesWritten, 
-		LPOVERLAPPED lpOverlapped); 
+BOOL CeWriteFile(
+		HANDLE hFile,
+		LPCVOID lpBuffer,
+		DWORD nNumberOfBytesToWrite,
+		LPDWORD lpNumberOfBytesWritten,
+		LPOVERLAPPED lpOverlapped);
+
+DWORD CeSetFilePointer(
+		HANDLE hFile,
+		LONG lDistanceToMove,
+		PLONG lpDistanceToMoveHigh,
+		DWORD dwMoveMethod);
+
+BOOL CeGetFileTime(
+		HANDLE hFile,
+		LPFILETIME lpCreationTime,
+		LPFILETIME lpLastAccessTime,
+		LPFILETIME lpLastWriteTime);
+
+BOOL CeSetFileTime(
+		HANDLE hFile,
+		LPFILETIME lpCreationTime,
+		LPFILETIME lpLastAccessTime,
+		LPFILETIME lpLastWriteTime);
 
 #endif /* SWIG */
 
@@ -158,46 +237,46 @@ BOOL CeWriteFile(
 #ifndef SWIG
 
 BOOL CeCopyFileA(
-		LPCSTR lpExistingFileName, 
-		LPCSTR lpNewFileName, 
+		LPCSTR lpExistingFileName,
+		LPCSTR lpNewFileName,
 		BOOL bFailIfExists);
 
 BOOL CeCopyFile(
-		LPCWSTR lpExistingFileName, 
-		LPCWSTR lpNewFileName, 
+		LPCWSTR lpExistingFileName,
+		LPCWSTR lpNewFileName,
 		BOOL bFailIfExists);
 
 BOOL CeCreateDirectory(
-		LPCWSTR lpPathName, 
+		LPCWSTR lpPathName,
 		LPSECURITY_ATTRIBUTES lpSecurityAttributes);
 
 BOOL CeDeleteFile(
 		LPCWSTR lpFileName);
 
 typedef struct _CE_FIND_DATA {
-	DWORD dwFileAttributes; 
-	FILETIME ftCreationTime; 
-	FILETIME ftLastAccessTime; 
-	FILETIME ftLastWriteTime; 
-	DWORD nFileSizeHigh; 
-	DWORD nFileSizeLow; 
-	DWORD dwOID; 
-	WCHAR cFileName[MAX_PATH]; 
-} CE_FIND_DATA, *LPCE_FIND_DATA, **LPLPCE_FIND_DATA; 
+	DWORD dwFileAttributes;
+	FILETIME ftCreationTime;
+	FILETIME ftLastAccessTime;
+	FILETIME ftLastWriteTime;
+	DWORD nFileSizeHigh;
+	DWORD nFileSizeLow;
+	DWORD dwOID;
+	WCHAR cFileName[MAX_PATH];
+} CE_FIND_DATA, *LPCE_FIND_DATA, **LPLPCE_FIND_DATA;
 
 BOOL CeFindAllFiles(
-		LPCWSTR szPath, 
-		DWORD dwFlags, 
-		LPDWORD lpdwFoundCount, 
+		LPCWSTR szPath,
+		DWORD dwFlags,
+		LPDWORD lpdwFoundCount,
 		LPLPCE_FIND_DATA ppFindDataArray);
 
 HANDLE CeFindFirstFile(
-		LPCWSTR lpFileName, 
+		LPCWSTR lpFileName,
 		LPCE_FIND_DATA lpFindFileData);
 
-BOOL CeFindNextFile( 
-		HANDLE hFindFile, 
-		LPCE_FIND_DATA lpFindFileData); 
+BOOL CeFindNextFile(
+		HANDLE hFindFile,
+		LPCE_FIND_DATA lpFindFileData);
 
 BOOL CeFindClose(
 		HANDLE hFindFile);
@@ -205,17 +284,17 @@ BOOL CeFindClose(
 DWORD CeGetFileAttributes(
 		LPCWSTR lpFileName);
 
-DWORD CeGetFileSize( 
-		HANDLE hFile, 
-		LPDWORD lpFileSizeHigh); 
+DWORD CeGetFileSize(
+		HANDLE hFile,
+		LPDWORD lpFileSizeHigh);
 
-DWORD CeGetSpecialFolderPath( 
-		int nFolder, 
-		DWORD nBufferLength, 
+DWORD CeGetSpecialFolderPath(
+		int nFolder,
+		DWORD nBufferLength,
 		LPWSTR lpBuffer);
 
 BOOL CeMoveFile(
-		LPCWSTR lpExistingFileName, 
+		LPCWSTR lpExistingFileName,
 		LPCWSTR lpNewFileName);
 
 BOOL CeRemoveDirectory(
@@ -225,6 +304,12 @@ BOOL CeSetFileAttributes(
 		LPCWSTR lpFileName,
 		DWORD dwFileAttributes);
 
+BOOL CeSHCreateShortcut(
+  LPCWSTR lpszShortcut,
+  LPCWSTR lpszTarget);
+
+BOOL CeSyncTimeToPc();
+
 #endif /* SWIG */
 
 
@@ -303,32 +388,32 @@ typedef struct _CEBLOB {
 } CEBLOB;
 
 typedef union _CEVALUNION {
-	short iVal; 
-	USHORT uiVal; 
-	long lVal; 
-	ULONG ulVal; 
+	short iVal;
+	USHORT uiVal;
+	long lVal;
+	ULONG ulVal;
 	FILETIME filetime;
-	LPWSTR lpwstr; 
-	CEBLOB blob; 
+	LPWSTR lpwstr;
+	CEBLOB blob;
 	BOOL boolVal;
 	double dblVal;
-} CEVALUNION; 
+} CEVALUNION;
 
-typedef struct _CEPROPVAL { 
+typedef struct _CEPROPVAL {
 	CEPROPID propid;
 	WORD wLenData;
 	WORD wFlags;
 	CEVALUNION val;
 } CEPROPVAL;
-typedef CEPROPVAL *PCEPROPVAL; 
+typedef CEPROPVAL *PCEPROPVAL;
 
 typedef struct _SORTORDERSPEC {
 	CEPROPID propid;
 	DWORD dwFlags;
-} SORTORDERSPEC; 
+} SORTORDERSPEC;
 
 typedef struct _CEDBASEINFO {
-	DWORD dwFlags; 
+	DWORD dwFlags;
 	WCHAR szDbaseName[CEDB_MAXDBASENAMELEN];
 	DWORD dwDbaseType;
 	WORD wNumRecords;
@@ -344,18 +429,18 @@ typedef struct _CEDB_FIND_DATA {
 } CEDB_FIND_DATA, *LPCEDB_FIND_DATA, **LPLPCEDB_FIND_DATA;
 
 CEOID CeCreateDatabase(
-		LPWSTR lpszName, 
-		DWORD dwDbaseType, 
-		WORD wNumSortOrder, 
+		LPWSTR lpszName,
+		DWORD dwDbaseType,
+		WORD wNumSortOrder,
 		SORTORDERSPEC *rgSortSpecs);
 
 BOOL CeDeleteDatabase(
 		CEOID oid);
 
 BOOL CeFindAllDatabases(
-		DWORD dwDbaseType, 
-		WORD wFlags, 
-		LPWORD cFindData, 
+		DWORD dwDbaseType,
+		WORD wFlags,
+		LPWORD cFindData,
 		LPLPCEDB_FIND_DATA ppFindData);
 
 HANDLE CeFindFirstDatabase(
@@ -365,31 +450,39 @@ CEOID CeFindNextDatabase(
 		HANDLE hEnum);
 
 HANDLE CeOpenDatabase(
-		PCEOID poid, 
-		LPWSTR lpszName, 
-		CEPROPID propid, 
-		DWORD dwFlags, 
-		HWND hwndNotify); 
+		PCEOID poid,
+		LPWSTR lpszName,
+		CEPROPID propid,
+		DWORD dwFlags,
+		HWND hwndNotify);
 
 CEOID CeReadRecordProps(
-		HANDLE hDbase, 
-		DWORD dwFlags, 
-		LPWORD lpcPropID, 
-		CEPROPID *rgPropID, 
-		LPBYTE *lplpBuffer, 
-		LPDWORD lpcbBuffer); 
+		HANDLE hDbase,
+		DWORD dwFlags,
+		LPWORD lpcPropID,
+		CEPROPID *rgPropID,
+		LPBYTE *lplpBuffer,
+		LPDWORD lpcbBuffer);
 
 CEOID CeSeekDatabase(
-		HANDLE hDatabase, 
-		DWORD dwSeekType, 
-		DWORD dwValue, 
+		HANDLE hDatabase,
+		DWORD dwSeekType,
+		DWORD dwValue,
 		LPDWORD lpdwIndex);
 
 CEOID CeWriteRecordProps(
-		HANDLE hDbase, 
-		CEOID oidRecord, 
-		WORD cPropID, 
-		CEPROPVAL *rgPropVal );
+		HANDLE hDbase,
+		CEOID oidRecord,
+		WORD cPropID,
+		CEPROPVAL *rgPropVal);
+
+BOOL CeDeleteRecord(
+    HANDLE hDatabase,
+    CEOID oidRecord);
+
+BOOL CeSetDatabaseInfo(
+    CEOID oidDbase,
+    CEDBASEINFO* pNewInfo);
 
 #endif /* SWIG */
 
@@ -412,77 +505,88 @@ CEOID CeWriteRecordProps(
 #define REG_LINK                    6
 #define REG_MULTI_SZ                7
 
+#define REG_CREATED_NEW_KEY         1
+#define REG_OPENED_EXISTING_KEY     2
+
 #ifndef SWIG
 
-LONG CeRegCreateKeyEx( 
-		HKEY hKey, 
-		LPCWSTR lpszSubKey, 
-		DWORD Reserved, 
-		LPWSTR lpszClass, 
-		DWORD ulOptions, 
-		REGSAM samDesired, 
-		LPSECURITY_ATTRIBUTES lpSecurityAttributes, 
-		PHKEY phkResult, 
+LONG CeRegCreateKeyEx(
+		HKEY hKey,
+		LPCWSTR lpszSubKey,
+		DWORD Reserved,
+		LPWSTR lpszClass,
+		DWORD ulOptions,
+		REGSAM samDesired,
+		LPSECURITY_ATTRIBUTES lpSecurityAttributes,
+		PHKEY phkResult,
 		LPDWORD lpdwDisposition);
 
 LONG CeRegOpenKeyEx(
-		HKEY hKey, 
-		LPCWSTR lpszSubKey, 
-		DWORD ulOptions, 
-		REGSAM samDesired, 
+		HKEY hKey,
+		LPCWSTR lpszSubKey,
+		DWORD ulOptions,
+		REGSAM samDesired,
 		PHKEY phkResult);
 
 LONG CeRegCloseKey(
 		HKEY hKey);
 
-LONG CeRegQueryInfoKey( 
-		HKEY hKey, 
-		LPWSTR lpClass, 
-		LPDWORD lpcbClass, 
-		LPDWORD lpReserved, 
-		LPDWORD lpcSubKeys, 
-		LPDWORD lpcbMaxSubKeyLen, 
-		LPDWORD lpcbMaxClassLen, 
-		LPDWORD lpcValues, 
-		LPDWORD lpcbMaxValueNameLen, 
-		LPDWORD lpcbMaxValueLen, 
-		LPDWORD lpcbSecurityDescriptor, 
+LONG CeRegDeleteKey(
+		HKEY hKey,
+		LPCWSTR lpszSubKey);
+
+LONG CeRegDeleteValue(
+		HKEY hKey,
+		LPCWSTR lpszValueName);
+
+LONG CeRegQueryInfoKey(
+		HKEY hKey,
+		LPWSTR lpClass,
+		LPDWORD lpcbClass,
+		LPDWORD lpReserved,
+		LPDWORD lpcSubKeys,
+		LPDWORD lpcbMaxSubKeyLen,
+		LPDWORD lpcbMaxClassLen,
+		LPDWORD lpcValues,
+		LPDWORD lpcbMaxValueNameLen,
+		LPDWORD lpcbMaxValueLen,
+		LPDWORD lpcbSecurityDescriptor,
 		PFILETIME lpftLastWriteTime);
 
-LONG CeRegQueryValueEx( 
-		HKEY hKey, 
-		LPCWSTR lpValueName, 
-		LPDWORD lpReserved, 
-		LPDWORD lpType, 
-		LPBYTE lpData, 
+LONG CeRegQueryValueEx(
+		HKEY hKey,
+		LPCWSTR lpValueName,
+		LPDWORD lpReserved,
+		LPDWORD lpType,
+		LPBYTE lpData,
 		LPDWORD lpcbData);
 
-LONG CeRegEnumValue( 
-		HKEY hKey, 
-		DWORD dwIndex, 
-		LPWSTR lpszValueName, 
-		LPDWORD lpcbValueName, 
-		LPDWORD lpReserved, 
-		LPDWORD lpType, 
-		LPBYTE lpData, 
+LONG CeRegEnumValue(
+		HKEY hKey,
+		DWORD dwIndex,
+		LPWSTR lpszValueName,
+		LPDWORD lpcbValueName,
+		LPDWORD lpReserved,
+		LPDWORD lpType,
+		LPBYTE lpData,
 		LPDWORD lpcbData);
 
-LONG CeRegEnumKeyEx( 
-		HKEY hKey, 
-		DWORD dwIndex, 
-		LPWSTR lpName, 
-		LPDWORD lpcbName, 
-		LPDWORD lpReserved, 
-		LPWSTR lpClass, 
-		LPDWORD lpcbClass, 
+LONG CeRegEnumKeyEx(
+		HKEY hKey,
+		DWORD dwIndex,
+		LPWSTR lpName,
+		LPDWORD lpcbName,
+		LPDWORD lpReserved,
+		LPWSTR lpClass,
+		LPDWORD lpcbClass,
 		PFILETIME lpftLastWriteTime);
 
-LONG CeRegSetValueEx( 
-		HKEY hKey, 
-		LPCWSTR lpValueName, 
-		DWORD Reserved, 
-		DWORD dwType, 
-		const BYTE *lpData, 
+LONG CeRegSetValueEx(
+		HKEY hKey,
+		LPCWSTR lpValueName,
+		DWORD Reserved,
+		DWORD dwType,
+		const BYTE *lpData,
 		DWORD cbData);
 
 /*
@@ -491,27 +595,27 @@ LONG CeRegSetValueEx(
 
 bool rapi_reg_create_key(
 		HKEY parent,
-		const char* name, 
+		const char* name,
 		HKEY* key);
 
 bool rapi_reg_open_key(
 		HKEY parent, const char* name, HKEY* key);
 
 bool rapi_reg_query_dword(
-		HKEY key, 
-		const char* name, 
+		HKEY key,
+		const char* name,
 		DWORD* value);
 
 bool rapi_reg_query_string(
-		HKEY key, 
-		const char* name, 
+		HKEY key,
+		const char* name,
 		char** value);
 
 #define rapi_reg_free_string(str) wstr_free_string(str)
 
 bool rapi_reg_set_dword(
-		HKEY key, 
-		const char* name, 
+		HKEY key,
+		const char* name,
 		DWORD value);
 
 bool rapi_reg_set_string(
@@ -585,9 +689,9 @@ bool rapi_reg_set_string(
 #define OBJTYPE_DIRECTORY   2
 #define OBJTYPE_DATABASE    3
 #define OBJTYPE_RECORD      4
-/* 
+/*
  * returned by CeOidGetInfo() for an ActiveSync notification when
- * an object has been deleted. 
+ * an object has been deleted.
  */
 #define OBJTYPE_DELETED     8
 
@@ -598,28 +702,28 @@ bool rapi_reg_set_string(
 
 #ifndef SWIG
 
-BOOL CeCheckPassword( 
+BOOL CeCheckPassword(
 		LPWSTR lpszPassword);
 
-typedef struct _PROCESS_INFORMATION { 
-	HANDLE hProcess; 
-	HANDLE hThread; 
-	DWORD dwProcessId; 
-	DWORD dwThreadId; 
+typedef struct _PROCESS_INFORMATION {
+	HANDLE hProcess;
+	HANDLE hThread;
+	DWORD dwProcessId;
+	DWORD dwThreadId;
 } PROCESS_INFORMATION;
 
 typedef PROCESS_INFORMATION* LPPROCESS_INFORMATION;
 
 BOOL CeCreateProcess(
-		LPCWSTR lpApplicationName, 
-		LPCWSTR lpCommandLine, 
-		void* lpProcessAttributes, 
-		void* lpThreadAttributes, 
-		BOOL bInheritHandles, 
-		DWORD dwCreationFlags, 
-		LPVOID lpEnvironment, 
-		LPWSTR lpCurrentDirectory, 
-		void* lpStartupInfo, 
+		LPCWSTR lpApplicationName,
+		LPCWSTR lpCommandLine,
+		void* lpProcessAttributes,
+		void* lpThreadAttributes,
+		BOOL bInheritHandles,
+		DWORD dwCreationFlags,
+		LPVOID lpEnvironment,
+		LPWSTR lpCurrentDirectory,
+		void* lpStartupInfo,
 		LPPROCESS_INFORMATION lpProcessInformation);
 
 DWORD CeGetLastError( void );
@@ -629,7 +733,7 @@ typedef struct STORE_INFORMATION {
 	DWORD dwFreeSize;
 } STORE_INFORMATION, *LPSTORE_INFORMATION;
 
-BOOL CeGetStoreInformation( 
+BOOL CeGetStoreInformation(
 		LPSTORE_INFORMATION lpsi);
 
 typedef struct _SYSTEM_INFO {
@@ -637,8 +741,8 @@ typedef struct _SYSTEM_INFO {
 	WORD wProcessorArchitecture;
 	WORD wReserved;
 	DWORD dwPageSize;
-	LPVOID lpMinimumApplicationAddress;
-	LPVOID lpMaximumApplicationAddress;
+	ULONG lpMinimumApplicationAddress;
+	ULONG lpMaximumApplicationAddress;
 	DWORD dwActiveProcessorMask;
 	DWORD dwNumberOfProcessors;
 	DWORD dwProcessorType;
@@ -647,7 +751,7 @@ typedef struct _SYSTEM_INFO {
 	WORD wProcessorRevision;
 } SYSTEM_INFO, *LPSYSTEM_INFO;
 
-void CeGetSystemInfo( 
+void CeGetSystemInfo(
 		LPSYSTEM_INFO lpSystemInfo);
 
 typedef struct _SYSTEM_POWER_STATUS_EX {
@@ -667,37 +771,37 @@ typedef struct _SYSTEM_POWER_STATUS_EX {
 
 BOOL CeGetSystemPowerStatusEx(PSYSTEM_POWER_STATUS_EX pSystemPowerStatus, BOOL refresh);
 
-typedef struct _CEOSVERSIONINFO{ 
-	DWORD dwOSVersionInfoSize; 
-	DWORD dwMajorVersion; 
-	DWORD dwMinorVersion; 
-	DWORD dwBuildNumber; 
-	DWORD dwPlatformId; 
-	WCHAR szCSDVersion[128]; 
-} CEOSVERSIONINFO, *LPCEOSVERSIONINFO; 
+typedef struct _CEOSVERSIONINFO{
+	DWORD dwOSVersionInfoSize;
+	DWORD dwMajorVersion;
+	DWORD dwMinorVersion;
+	DWORD dwBuildNumber;
+	DWORD dwPlatformId;
+	WCHAR szCSDVersion[128];
+} CEOSVERSIONINFO, *LPCEOSVERSIONINFO;
 
 BOOL CeGetVersionEx(
 		LPCEOSVERSIONINFO lpVersionInformation);
 
 typedef struct _CEFILEINFO {
-	DWORD dwAttributes; 
-	CEOID oidParent; 
-	WCHAR szFileName[MAX_PATH]; 
-	FILETIME ftLastChanged; 
-	DWORD dwLength; 
-} CEFILEINFO; 
+	DWORD dwAttributes;
+	CEOID oidParent;
+	WCHAR szFileName[MAX_PATH];
+	FILETIME ftLastChanged;
+	DWORD dwLength;
+} CEFILEINFO;
 
 typedef struct _CEDIRINFO {
-	DWORD dwAttributes; 
-	CEOID oidParent; 
-	WCHAR szDirName[MAX_PATH]; 
-} CEDIRINFO; 
+	DWORD dwAttributes;
+	CEOID oidParent;
+	WCHAR szDirName[MAX_PATH];
+} CEDIRINFO;
 
 typedef struct _CERECORDINFO {
-	CEOID oidParent; 
-} CERECORDINFO; 
+	CEOID oidParent;
+} CERECORDINFO;
 
-typedef struct _CEOIDINFO { 
+typedef struct _CEOIDINFO {
 	WORD wObjType;
 	WORD wPad;
 	union {
@@ -706,24 +810,40 @@ typedef struct _CEOIDINFO {
 		CEDBASEINFO infDatabase;
 		CERECORDINFO infRecord;
 	} u;
-} CEOIDINFO; 
+} CEOIDINFO;
 
 BOOL CeOidGetInfo(
-		CEOID oid, 
-		CEOIDINFO *poidInfo); 
+		CEOID oid,
+		CEOIDINFO *poidInfo);
 
 HRESULT CeProcessConfig(LPCWSTR config, DWORD flags, LPWSTR* reply);
 
-HRESULT CeStartReplication( void );
+BOOL CeStartReplication( void );
+
+HRESULT CeSyncStart( LPCWSTR params );
+
+HRESULT CeSyncResume( void );
+
+HRESULT CeSyncPause( void );
+
+#define SYSMEM_CHANGED        0
+#define SYSMEM_MUSTREBOOT     1
+#define SYSMEM_REBOOTPENDING  2
+#define SYSMEM_FAILED         3
 
 BOOL CeGetSystemMemoryDivision(
-    LPDWORD lpdwStoragePages, 
-    LPDWORD lpdwRamPages, 
+    LPDWORD lpdwStoragePages,
+    LPDWORD lpdwRamPages,
     LPDWORD lpdwPageSize);
 
 DWORD CeSetSystemMemoryDivision(
     DWORD dwStoragePages);
 
+BOOL CeRegCopyFile(LPCWSTR filename);
+BOOL CeRegRestoreFile(LPCWSTR filename);
+
+BOOL CeKillAllApps();
+
 #endif /* SWIG */
 
 /*
@@ -739,36 +859,36 @@ ULONG IRAPIStream_Release(IRAPIStream* stream);
 
 HRESULT IRAPIStream_Read(
 		IRAPIStream* stream,
-		void *pv, 
-		ULONG cb, 
+		void *pv,
+		ULONG cb,
 		ULONG *pcbRead);
 
 HRESULT IRAPIStream_Write(
 		IRAPIStream* stream,
-		void const *pv, 
-		ULONG cb, 
+		void const *pv,
+		ULONG cb,
 		ULONG *pcbWritten);
 
 int IRAPIStream_GetRawSocket(IRAPIStream* stream);
 
-HRESULT CeRapiInvoke( 
-		LPCWSTR pDllPath, 
-		LPCWSTR pFunctionName, 
-		DWORD cbInput, 
-		const BYTE *pInput, 
-		DWORD *pcbOutput, 
-		BYTE **ppOutput, 
-		IRAPIStream **ppIRAPIStream, 
+HRESULT CeRapiInvoke(
+		LPCWSTR pDllPath,
+		LPCWSTR pFunctionName,
+		DWORD cbInput,
+		const BYTE *pInput,
+		DWORD *pcbOutput,
+		BYTE **ppOutput,
+		IRAPIStream **ppIRAPIStream,
 		DWORD dwReserved);
 
 HRESULT CeRapiInvokeA(
-		LPCSTR pDllPath, 
-		LPCSTR pFunctionName, 
-		DWORD cbInput, 
-		const BYTE *pInput, 
-		DWORD *pcbOutput, 
-		BYTE **ppOutput, 
-		IRAPIStream **ppIRAPIStream, 
+		LPCSTR pDllPath,
+		LPCSTR pFunctionName,
+		DWORD cbInput,
+		const BYTE *pInput,
+		DWORD *pcbOutput,
+		BYTE **ppOutput,
+		IRAPIStream **ppIRAPIStream,
 		DWORD dwReserved);
 
 #endif /* SWIG */
@@ -778,6 +898,5 @@ HRESULT CeRapiInvokeA(
 }
 #endif
 
-
 #endif
 
