@@ -1,4 +1,4 @@
-/* $Id: rapi_context.c,v 1.8 2004/05/22 15:56:55 twogood Exp $ */
+/* $Id: rapi_context.c 2575 2006-09-20 18:11:36Z voc $ */
 #undef __STRICT_ANSI__
 #define _GNU_SOURCE
 #include "rapi_context.h"
@@ -7,6 +7,7 @@
 #include <string.h>
 #include <sys/types.h>
 #include <signal.h>
+#include <errno.h>
 
 #define CERAPI_E_ALREADYINITIALIZED  0x8004101
 
@@ -18,28 +19,36 @@
 #define rapi_context_trace(args...)    synce_trace(args)
 #define rapi_context_warning(args...)  synce_warning(args)
 #else
-#define rapi_context_trace(args...)
-#define rapi_context_warning(args...)
+#define rapi_context_trace(args...)    synce_trace(args)
+#define rapi_context_warning(args...)  synce_warning(args)
 #endif
 #define rapi_context_error(args...)    synce_error(args)
 
 static RapiContext* current_context;
 
+extern struct rapi_ops_s rapi_ops;
+extern struct rapi_ops_s rapi2_ops;
+
 RapiContext* rapi_context_current()/*{{{*/
 {
 	/* TODO: make thread-safe version of this with thread private variables */
 
 	if (!current_context)
 	{
-		current_context = rapi_context_new();
+		rapi_context_set(rapi_context_new());
 	}
 
 	return current_context;
 }/*}}}*/
 
+void rapi_context_set(RapiContext* context)
+{
+  current_context = context;
+}
+
 RapiContext* rapi_context_new()/*{{{*/
 {
-	RapiContext* context = calloc(sizeof(RapiContext), 1);
+	RapiContext* context = calloc(1, sizeof(RapiContext));
 
 	if (context)
 	{
@@ -61,8 +70,8 @@ void rapi_context_free(RapiContext* context)/*{{{*/
 {
 	if (context)
 	{
-    if (current_context == context)
-      current_context = NULL;
+    if (context == rapi_context_current())
+      rapi_context_set(NULL);
 
 		rapi_buffer_free(context->send_buffer);
 		rapi_buffer_free(context->recv_buffer);
@@ -81,8 +90,11 @@ HRESULT rapi_context_connect(RapiContext* context)
 		/* Fail immediately */
 		return CERAPI_E_ALREADYINITIALIZED;
 	}
-  
-  info = synce_info_new(NULL);
+
+  if (context->info)
+    info = context->info;
+  else
+    info = synce_info_new(NULL);
   if (!info)
 	{
 		synce_error("Failed to get connection info");
@@ -97,8 +109,11 @@ HRESULT rapi_context_connect(RapiContext* context)
 
 	if (kill(info->dccm_pid, 0) < 0)
 	{
-		synce_error("DCCM not running with pid %i", info->dccm_pid);
-		goto fail;
+		if (errno != EPERM)
+		{
+			synce_error("DCCM not running with pid %i", info->dccm_pid);
+			goto fail;
+		}
 	}
 
 	if (!info->ip)
@@ -107,62 +122,73 @@ HRESULT rapi_context_connect(RapiContext* context)
 		goto fail;
 	}
 
-	if ( !synce_socket_connect(context->socket, info->ip, RAPI_PORT) )
-	{
-		synce_error("failed to connect to %s", info->ip);
-		goto fail;
-	}
+    if (info->transport == NULL || strncmp(info->transport,  "ppp", 3) == 0) {
+        if ( !synce_socket_connect(context->socket, info->ip, RAPI_PORT) )
+        {
+            synce_error("failed to connect to %s", info->ip);
+		  goto fail;
+        }
 
-	if (info->password && strlen(info->password))
-	{
-		bool password_correct = false;
+        if (info->password && strlen(info->password))
+        {
+            bool password_correct = false;
 
-		if (!synce_password_send(context->socket, info->password, info->key))
-		{
-			synce_error("failed to send password");
-      result = E_ACCESSDENIED;
-			goto fail;
-		}
+            if (!synce_password_send(context->socket, info->password, info->key))
+            {
+                synce_error("failed to send password");
+                result = E_ACCESSDENIED;
+                goto fail;
+            }
 
-		if (!synce_password_recv_reply(context->socket, 1, &password_correct))
-		{
-			synce_error("failed to get password reply");
-      result = E_ACCESSDENIED;
-			goto fail;
-		}
+            if (!synce_password_recv_reply(context->socket, 1, &password_correct))
+            {
+                synce_error("failed to get password reply");
+                result = E_ACCESSDENIED;
+                goto fail;
+            }
 
-		if (!password_correct)
-		{
-			synce_error("invalid password");
-      result = E_ACCESSDENIED;
-			goto fail;
-		}
-	}
+            if (!password_correct)
+            {
+                synce_error("invalid password");
+                result = E_ACCESSDENIED;
+                goto fail;
+            }
+        }
+        context->rapi_ops = &rapi_ops;
+    } else {
+        if ( !synce_socket_connect_proxy(context->socket, info->ip) )
+        {
+            synce_error("failed to connect to proxy for %s", info->ip);
+            goto fail;
+        }
+        context->rapi_ops = &rapi2_ops;
+    }
 
 	context->is_initialized = true;
 	result = S_OK;
 
 fail:
-  synce_info_destroy(info);
+  if (!context->info)
+    synce_info_destroy(info);
 	return result;
 }
 
 bool rapi_context_begin_command(RapiContext* context, uint32_t command)/*{{{*/
 {
 	rapi_context_trace("command=0x%02x", command);
-	
+
 	rapi_buffer_free_data(context->send_buffer);
-	
+
 	if ( !rapi_buffer_write_uint32(context->send_buffer, command) )
 		return false;
 
 	return true;
 }/*}}}*/
-	
+
 bool rapi_context_call(RapiContext* context)/*{{{*/
 {
   context->rapi_error = E_UNEXPECTED;
-  
+
 	if ( !rapi_buffer_send(context->send_buffer, context->socket) )
 	{
 		rapi_context_error("rapi_buffer_send failed");
@@ -207,3 +233,25 @@ bool rapi_context_call(RapiContext* context)/*{{{*/
 	return true;
 }/*}}}*/
 
+bool rapi2_context_call(RapiContext* context)/*{{{*/
+{
+    context->rapi_error = E_UNEXPECTED;
+
+    if ( !rapi_buffer_send(context->send_buffer, context->socket) )
+    {
+        rapi_context_error("rapi_buffer_send failed");
+        context->rapi_error = E_FAIL;
+        return false;
+    }
+
+    if ( !rapi_buffer_recv(context->recv_buffer, context->socket) )
+    {
+        rapi_context_error("rapi_buffer_recv failed");
+        context->rapi_error = E_FAIL;
+        return false;
+    }
+
+    context->rapi_error = S_OK;
+    return true;
+}/*}}}*/
+
