@@ -1,10 +1,12 @@
-/* $Id: rapi_context.h,v 1.4 2004/05/22 15:56:55 twogood Exp $ */
+/* $Id: rapi_context.h 2355 2006-04-07 18:47:20Z voc $ */
 #ifndef __rapi_context_h__
 #define __rapi_context_h__
 
 #include "rapi_buffer.h"
 #include <synce_socket.h>
 
+struct rapi_ops_s;
+
 typedef struct _RapiContext
 {
 	RapiBuffer* send_buffer;
@@ -13,8 +15,10 @@ typedef struct _RapiContext
 	uint32_t result_1;
 	uint32_t result_2;
 	uint32_t last_error;
-  uint32_t rapi_error;
+    uint32_t rapi_error;
 	bool is_initialized;
+    SynceInfo* info;
+    struct rapi_ops_s *rapi_ops;
 } RapiContext;
 
 /**
@@ -22,13 +26,18 @@ typedef struct _RapiContext
  */
 RapiContext* rapi_context_current();
 
+/**
+ * Set current RapiContext
+ */
+void rapi_context_set(RapiContext* context);
+
 /**
  * Create new context
  */
 RapiContext* rapi_context_new();
 
 /**
- * Free context 
+ * Free context
  */
 void rapi_context_free(RapiContext* context);
 
@@ -47,5 +56,7 @@ bool rapi_context_begin_command(RapiContext* context, uint32_t command);
  */
 bool rapi_context_call(RapiContext* context);
 
+bool rapi2_context_call(RapiContext* context);
+
 #endif
 
